from gi.repository import Caja, GObject

class ExampleMenuProvider(GObject.GObject, Caja.MenuProvider):
    def __init__(self):
        pass
        
    def get_file_items(self, window, files):
        top_menuitem = Caja.MenuItem(name='ExampleMenuProvider::Foo', 
                                         label='Foo', 
                                         tip='',
                                         icon='')

        submenu = Caja.Menu()
        top_menuitem.set_submenu(submenu)

        sub_menuitem = Caja.MenuItem(name='ExampleMenuProvider::Bar', 
                                         label='Bar', 
                                         tip='',
                                         icon='')
        submenu.append_item(sub_menuitem)

        return top_menuitem,

    def get_background_items(self, window, file):
        submenu = Caja.Menu()
        submenu.append_item(Caja.MenuItem(name='ExampleMenuProvider::Bar2', 
                                         label='Bar2', 
                                         tip='',
                                         icon=''))

        menuitem = Caja.MenuItem(name='ExampleMenuProvider::Foo2', 
                                         label='Foo2', 
                                         tip='',
                                         icon='')
        menuitem.set_submenu(submenu)

        return menuitem,




# This example is contributed by Martin Enlund
import os

from gi.repository import Caja, GObject, Gio

TERMINAL_SCHEMA = 'org.mate.applications-terminal'
TERMINAL_KEY = 'exec'

class OpenTerminalExtension(Caja.MenuProvider, GObject.GObject):
    def __init__(self):
        self.gsettings = Gio.Settings.new(TERMINAL_SCHEMA)
        
    def _open_terminal(self, file):
        filename = file.get_location().get_path()
        terminal = self.gsettings[TERMINAL_KEY]

        os.chdir(filename)
        os.system('%s &' % terminal)
        
    def menu_activate_cb(self, menu, file):
        self._open_terminal(file)
        
    def menu_background_activate_cb(self, menu, file): 
        self._open_terminal(file)
       
    def get_file_items(self, window, files):
        if len(files) != 1:
            return
        
        file = files[0]
        if not file.is_directory() or file.get_uri_scheme() != 'file':
            return
        
        item = Caja.MenuItem(name='CajaPython::openterminal_file_item',
                                 label='Open Terminal' ,
                                 tip='Open Terminal In %s' % file.get_name())
        item.connect('activate', self.menu_activate_cb, file)
        return [item]

    def get_background_items(self, window, file):
        item = Caja.MenuItem(name='CajaPython::openterminal_item',
                                 label='Open Terminal Here',
                                 tip='Open Terminal In This Directory')
        item.connect('activate', self.menu_background_activate_cb, file)
        return [item]



# This Python caja extension only consider files/folders with a mixed
# upper/lower case name. For those, the following is featured:
# - an emblem on the icon,
# - contextual menu entry.
# - a list view "Mixed" column,
# - a property page,
# - A top area widget.

import os

from gi.repository import Caja, GObject, Gtk


class Mixed(GObject.GObject,
                Caja.InfoProvider,
                Caja.ColumnProvider,
                Caja.MenuProvider,
                Caja.PropertyPageProvider,
                Caja.LocationWidgetProvider):

    emblem = 'favorite-symbolic.symbolic'       # Use one of the stock emblems.

    # Private methods.

    def _file_has_mixed_name(self, cajafile):
        name = cajafile.get_name()
        if name.upper() != name and name.lower() != name:
            return 'mixed'
        return ''

    # Caja.InfoProvider implementation.

    def update_file_info(self, cajafile):
        mixed = self._file_has_mixed_name(cajafile)
        cajafile.add_string_attribute('mixed', mixed)
        if mixed:
            cajafile.add_emblem(self.emblem)

    # Caja.ColumnProvider implementation.

    def get_columns(self):
        return [
            Caja.Column(
                name        = 'Mixed::mixed_column',
                attribute   = 'mixed',
                label       = 'Mixed',
                description = 'Column added by the mixed extension'
            )
        ]

    # Caja.MenuProvider implementation.

    def get_file_items(self, window, cajafiles):
        menuitems = []
        if len(cajafiles) == 1:
            for cajafile in cajafiles:
                mixed = cajafile.get_string_attribute('mixed')
                if mixed:
                    filename = cajafile.get_name()
                    menuitem = Caja.MenuItem(
                        name  = 'Mixed::FileMenu',
                        label = 'Mixed: %s has a mixed case name' % filename,
                        tip   = '',
                        icon  = ''
                    )
                    menuitems.append(menuitem)

        return menuitems

    def get_background_items(self, window, folder):
        mixed = self._file_has_mixed_name(folder)
        if not mixed:
            return []
        return [
            Caja.MenuItem(
                name  = 'Mixed::BackgroundMenu',
                label = 'Mixed: you are browsing a directory with a mixed case name',
                tip   = '',
                icon  = ''
            )
        ]

    # Caja.PropertyPageProvider implementation.

    def get_property_pages(self, cajafiles):
        pages = []
        if len(cajafiles) == 1:
            for cajafile in cajafiles:
                if self._file_has_mixed_name(cajafile):
                    page_label = Gtk.Label('Mixed')
                    page_label.show()
                    hbox = Gtk.HBox(homogeneous = False, spacing = 4)
                    hbox.show()
                    name_label = Gtk.Label(cajafile.get_name())
                    name_label.show()
                    comment_label = Gtk.Label('has a mixed-case name')
                    comment_label.show()
                    hbox.pack_start(name_label, False, False, 0)
                    hbox.pack_start(comment_label, False, False, 0)
                    pages.append(
                        Caja.PropertyPage(
                            name  = 'Mixed::PropertyPage',
                            label = page_label,
                            page  = hbox
                        )
                    )

        return pages

    # Caja.LocationWidgetProvider implementation.

    def get_widget(self, uri, window):
        cajafile = Caja.FileInfo.create_for_uri(uri)
        if not self._file_has_mixed_name(cajafile):
            return None
        label = Gtk.Label('In mixed-case directory ' + cajafile.get_name())
        label.show()
        return label



SUPPORTED_FORMATS = 'image/jpeg', 'image/png'
BACKGROUND_SCHEMA = 'org.mate.background'
BACKGROUND_KEY = 'picture-filename'

from gi.repository import Caja, GObject, Gio


class BackgroundImageExtension(GObject.GObject, Caja.MenuProvider):
    def __init__(self):
        self.bgsettings = Gio.Settings.new(BACKGROUND_SCHEMA)
    
    def menu_activate_cb(self, menu, file):
        if file.is_gone():
            return

        if file.get_uri_scheme() == 'file':
            self.bgsettings[BACKGROUND_KEY] = file.get_location().get_path()
        
    def get_file_items(self, window, files):
        if len(files) != 1:
            return

        file = files[0]

        # We're only going to put ourselves on images context menus
        if not file.get_mime_type() in SUPPORTED_FORMATS:
            return

        # Mate can only handle file:
        # In the future we might want to copy the file locally
        if file.get_uri_scheme() != 'file':
            return

        item = Caja.MenuItem(name='Caja::set_background_image',
                                 label='Use as background image',
                                 tip='Set the current image as a background image')
        item.connect('activate', self.menu_activate_cb, file)
        return [item]

    def get_background_items(self, window, file):
        return []



from gi.repository import Caja, Gtk, GObject

class LocationProviderExample(GObject.GObject, Caja.LocationWidgetProvider):
    def __init__(self):
        pass
    
    def get_widget(self, uri, window):
        entry = Gtk.Entry()
        entry.set_text(uri)
        entry.show()
        return entry
